About
=====

The `Diofant`_ project is a fork of the `SymPy`_, started by Sergey B
Kirpichev, last regular `SymPy`_'s commit is :commit:`cbdd072`, (22
Feb 2015).  The git history goes back to 2007.

The project was named after the Diophantus of Alexandria.  His
"Arithmetica" is one of the earliest known texts that use symbols in
equations.  "Diofant" is a transliteration of Диофант, from Russian.

License
-------

Unless stated otherwise, all files in the `Diofant`_ project are
licensed using the new BSD license:

.. include:: ../LICENSE.rst

SymPy
-----

`SymPy`_ is a team project and it was developed by a lot of people.
Please refer to the `AUTHORS
<https://github.com/sympy/sympy/blob/master/AUTHORS>`_ file in the
`SymPy repository <https://github.com/sympy/sympy/>`_ for up-to-date
list of contributors.

Please refer to the `SymPy`_'s `README.rst
<https://github.com/sympy/sympy/blob/master/README.rst>`_ for a brief
history of the `SymPy`_ project.  It was started by Ondřej Čertík in
2005, he is still active in the community, but is too busy with work
and family to play a lead development role.  Unfortunately, his
remaining activity neither constructive nor productive anymore and
`SymPy`_ just slowly dies now: most former contributors are inactive
or explicitly leaving this "friendly and welcoming" project, some
developers even don't want to be mentioned in the context of this
project and its derivatives.  Current maintainer continue bad practice
of blocking unpleasant opinions and even delete bugreports.

This unfortunate situation was major reason to fork the `SymPy`_ as
the `Diofant`_ project.  Development in the new project will be open
and public, without hidden double standards, centered about good,
proved code and not the project popularity counters.

.. _SymPy : https://www.sympy.org/
.. _Diofant : https://diofant.readthedocs.io/en/latest/
